pub struct AnalyzerContext { /* private fields */ }Expand description
Context that stores the results of analyzer computations.
The AnalyzerContext provides a centralized storage for metrics computed by different analyzers, allowing for efficient access and serialization of results.
Example
use term_guard::analyzers::{AnalyzerContext, MetricValue};
let mut context = AnalyzerContext::new();
// Store metrics from different analyzers
context.store_metric("size", MetricValue::Long(1000));
context.store_metric("completeness.user_id", MetricValue::Double(0.98));
// Retrieve metrics
if let Some(size) = context.get_metric("size") {
println!("Dataset size: {}", size);
}
// Get all metrics for a specific analyzer
let completeness_metrics = context.get_analyzer_metrics("completeness");Implementations
Sourceimpl AnalyzerContext
impl AnalyzerContext
Sourcepub fn with_dataset(dataset_name: impl Into<String>) -> Self
pub fn with_dataset(dataset_name: impl Into<String>) -> Self
Creates a new context with the given dataset name.
Sourcepub fn store_metric(&mut self, key: impl Into<String>, value: MetricValue)
pub fn store_metric(&mut self, key: impl Into<String>, value: MetricValue)
Stores a metric value with the given key.
Arguments
key- The metric key, typically in format “analyzer_name.metric_name”value- The metric value to store
Sourcepub fn store_analyzer_metric(
&mut self,
analyzer_name: &str,
metric_name: &str,
value: MetricValue,
)
pub fn store_analyzer_metric( &mut self, analyzer_name: &str, metric_name: &str, value: MetricValue, )
Stores a metric with a composite key built from analyzer and metric names.
Arguments
analyzer_name- The name of the analyzermetric_name- The name of the specific metricvalue- The metric value to store
Sourcepub fn get_metric(&self, key: &str) -> Option<&MetricValue>
pub fn get_metric(&self, key: &str) -> Option<&MetricValue>
Retrieves a metric value by key.
Sourcepub fn get_analyzer_metrics(
&self,
analyzer_name: &str,
) -> HashMap<String, &MetricValue>
pub fn get_analyzer_metrics( &self, analyzer_name: &str, ) -> HashMap<String, &MetricValue>
Retrieves all metrics for a specific analyzer.
Returns metrics whose keys start with the analyzer name followed by a dot.
Sourcepub fn all_metrics(&self) -> &HashMap<String, MetricValue>
pub fn all_metrics(&self) -> &HashMap<String, MetricValue>
Returns all stored metrics.
Sourcepub fn record_error(
&mut self,
analyzer_name: impl Into<String>,
error: AnalyzerError,
)
pub fn record_error( &mut self, analyzer_name: impl Into<String>, error: AnalyzerError, )
Records an error that occurred during analysis.
Sourcepub fn errors(&self) -> &[AnalysisError]
pub fn errors(&self) -> &[AnalysisError]
Returns all recorded errors.
Sourcepub fn has_errors(&self) -> bool
pub fn has_errors(&self) -> bool
Checks if any errors occurred during analysis.
Sourcepub fn metadata(&self) -> &AnalysisMetadata
pub fn metadata(&self) -> &AnalysisMetadata
Returns the analysis metadata.
Sourcepub fn metadata_mut(&mut self) -> &mut AnalysisMetadata
pub fn metadata_mut(&mut self) -> &mut AnalysisMetadata
Returns a mutable reference to the analysis metadata.
Sourcepub fn merge(&mut self, other: AnalyzerContext)
pub fn merge(&mut self, other: AnalyzerContext)
Merges another context into this one.
Metrics from the other context will overwrite existing metrics with the same key.
Sourcepub fn summary(&self) -> AnalysisSummary
pub fn summary(&self) -> AnalysisSummary
Creates a summary of the analysis results.